@@ -137,6 +137,13 @@ CNVScopeui<-fluidPage(theme=shinytheme("flatly"), #shinythemes::themeSelector()
                                                                                conditionalPanel("input.data_source== 'linreg_osteosarcoma_CNVkit'",
                                                                                                 checkboxInput('plot_points_toggle',"Plot Structural Variants",value = FALSE), 
                                                                                                 checkboxInput('lumpy_points_toggle',"Plot Lumpy SVs",value = FALSE)),
+                                                                               conditionalPanel("input.data_source== 'TCGA_NBL_low_pass'",
+                                                                                                checkboxInput('pval_filter_toggle',"P-value filter",value = FALSE),
+                                                                                                checkboxInput("genes_toggle","Show Genes on Tooltip",value=TRUE),
+                                                                                                selectInput('fdr_correction', 'FDR p-value correction', c("chromosome_pair","genome"), selected = "chromosome_pair"),
+                                                                                                selectInput('cor_method', 'Correlation Method', c("pearson","spearman","kendall","spearman - pearson"), selected = "pearson"),
+                                                                                                selectInput('visval', 'Visualized Relationship Metric', c("-log(Linear Regression P-value) * correlation sign","Correlation"), selected = "Correlation")
+                                                                               ),
                                                                                textInput('gene_input_row',"row_gene",NULL),
                                                                                textInput('loc_input_row',"row_location",NULL),
                                                                                textInput('gene_input_col',"col_gene",NULL),
